.. role:: raw-html-m2r(raw)
   :format: html


:raw-html-m2r:`<div align="center">
    <a href="https://pypi.org/project/discord-components"><img src="https://raw.githubusercontent.com/kiki7000/discord.py-components/master/.github/logo.png" alt="discord-components logo" height="128" style="border-radius: 50%"></a>
    <h1>discord-components</h1>
</div>`

:raw-html-m2r:`<div align="center">
        <a href="https://travis-ci.com/kiki7000/discord.py-components"><img src="https://travis-ci.com/kiki7000/discord.py-components.svg?branch=master" alt="Build Status"></a>
        <a href="https://pypi.org/project/discord-components"><img src="https://badge.fury.io/py/discord-components.svg" alt="PyPI version"></a>
        <a href="https://pypi.org/project/discord-components"><img src="https://img.shields.io/pypi/dm/discord-components" alt="PyPI downloads"></a>
</div>`


.. raw:: html

   <p align="center">
       <h3>An unofficial third party library of discord.py for discord components.</h3>
   </p>


Welcome!
--------

Discord components are cool, but discord.py will support it on version 2.0. It
is hard to wait, so we made a third-party library for using components such as
buttons or selects!

This project is open source ⭐.

Also, there is an `official discord server <https://discord.gg/pKM6stqPxS>`_\ , so
if you have any questions, feel free to ask it on this server.

Features
--------


* You can use message components and handle component interactions easily!
* Third-party of discord.py.

Docs
----


* `Gitbook version <https://devkiki7000.gitbook.io/discord-components>`_ (Up to
  date)
* `Sphinx Version <https://discord-components.readthedocs.io/en/0.5.2.4>`_
  (Currently outdated)

Install
-------

.. code-block::

   pip install --upgrade discord-components

Example
-------

You can see many examples
`here <https://github.com/kiki7000/discord.py-components/tree/master/examples>`_.

License
-------

This project is under the MIT License.

